======
wBuild
======



.. image:: https://pyup.io/repos/github/wachutka/wbuild/shield.svg
     :target: https://pyup.io/repos/github/wachutka/wbuild/
     :alt: Updates


Automtic build tool for R Reports



Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

